@@ -17,13 +17,17 @@ use JSON qw/decode_json/;
 use WWW::Mechanize;
 use Path::Tiny;
 
-our $VERSION = version->new('0.5.6');
+our $VERSION = version->new('0.5.7');
 
 extends 'Group::Git';
 
 has '+recurse' => (
     default => 1,
 );
+has 'mech' => (
+    is      => 'rw',
+    default => sub { WWW::Mechanize->new; },
+);
 
 sub _httpenc {
     my ($str) = @_;
@@ -82,7 +86,7 @@ Group::Git::Stash - Adds reading all repositories you have access to on your loc
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Stash version 0.5.6.
+This documentation refers to Group::Git::Stash version 0.5.7.
 
 =head1 SYNOPSIS
 
@@ -94,6 +98,8 @@ This documentation refers to Group::Git::Stash version 0.5.6.
            username => 'joeblogs@example.com',
            password => 'myverysecurepassword',
        },
+       # resursive is turned on by default for stash to allow for stash projects
+       recurse => 1,
    );
 
    # list all repositories
@@ -107,11 +113,20 @@ This documentation refers to Group::Git::Stash version 0.5.6.
 
 =head1 DESCRIPTION
 
-Reads all repositories for the configured user (if none set user will be
-prompted to enter one as well as a password)
+Reads all repositories that the configured user has access to. Note: if no
+user is set up (or no password is supplied) then you will bie prompted to
+enter the username and/or password.
 
 =head1 SUBROUTINES/METHODS
 
+=over 4
+
+=item mech
+
+Property for storing the L<WWW::Mechanize> object for talking to stash
+
+=back
+
 =head1 DIAGNOSTICS
 
 =head1 CONFIGURATION AND ENVIRONMENT
